import { type EvalRunEventProvider, type EvalRunStartEvent, type EvalRunCompleteEvent } from '@agentuity/core';
/**
 * An implementation of the EvalRunEventProvider which writes to JSON files
 */
export declare class JSONEvalRunEventProvider implements EvalRunEventProvider {
    private exportDir;
    constructor(exportDir: string);
    /**
     * called when the eval run starts
     *
     * @param event EvalRunStartEvent
     */
    start(event: EvalRunStartEvent): Promise<void>;
    /**
     * called when the eval run completes
     *
     * @param event EvalRunCompleteEvent
     */
    complete(event: EvalRunCompleteEvent): Promise<void>;
}
//# sourceMappingURL=json.d.ts.map